#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test-py39"
%define psuffix -test-py39
%define skip_python38 1
%define skip_python310 1
%define skip_python311 1
%define skip_python312 1
%endif
%if "%{flavor}" == "test-py310"
%define psuffix -test-py310
%define skip_python38 1
%define skip_python39 1
%define skip_python311 1
%define skip_python312 1
%endif
%if "%{flavor}" == "test-py311"
%define psuffix -test-py311
%define skip_python38 1
%define skip_python39 1
%define skip_python310 1
%define skip_python312 1
%endif
%if "%{flavor}" == "test-py312"
%define psuffix -test-py312
%define skip_python38 1
%define skip_python39 1
%define skip_python310 1
%define skip_python311 1
%endif
%if "%{flavor}" == ""
%define psuffix %{nil}
%bcond_with test
%else
%bcond_without test
ExclusiveArch:  x86_64
%endif
%{?sle15_python_module_pythons}
Name:           python-pythran%{psuffix}
Version:        0.14.0
Release:        2.4
Summary:        Ahead of Time compiler for numeric kernels
License:        BSD-3-Clause
URL:            https://github.com/serge-sans-paille/pythran
# Tests are only availble in github archive
Source0:        https://github.com/serge-sans-paille/pythran/archive/refs/tags/%{version}.tar.gz#/pythran-%{version}-gh.tar.gz
Source99:       python-pythran-rpmlintrc
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-beniget >= 0.4.0
Requires:       python-gast >= 0.5.0
Requires:       python-ply >= 3.4
Requires(post): update-alternatives
Requires(postun):update-alternatives
# SECTION This is a package that compiles code, the runtime requires devel packages, inspired by fedora package
Requires:       boost-devel
Requires:       gcc-c++
Requires:       openblas-devel
Requires:       python-devel
Requires:       python-numpy-devel
# Not available, use bundled
# Requires:  xsimd-devel >= 8
# /SECTION
%if %{with test}
BuildRequires:  %{python_module ipython}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pythran = %{version}}
BuildRequires:  %{python_module wheel}
BuildRequires:  gcc-c++
BuildRequires:  unzip
%endif
BuildArch:      noarch
%python_subpackages

%description
Ahead of Time compiler for numeric kernels

%prep
%autosetup -p1 -n pythran-%{version}

find -name '*.hpp' -exec chmod -x {} +
sed -i '1{/env python/d}' pythran/run.py

# Remove bundled header libs and use the ones from system
rm -r third_party/boost
cat >> setup.cfg << EOF
[build_py]
no_boost=True
EOF

# Register pytest.mark.module
cat >> pytest.ini << EOF
# https://github.com/serge-sans-paille/pythran/pull/286
[pytest]
markers =
    module: execute module annotate class
EOF
# The tests have some cflags in them
# We need to adapt the flags to play nicely with other obs flags
# E.g. fortify source implies at least -O1
sed -i -e 's/-O0/-O1/g' -e 's/-Werror/-w/g' pythran/tests/__init__.py

%build
%pyproject_wheel

%if !%{with test}
%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pythran
%python_clone -a %{buildroot}%{_bindir}/pythran-config
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
export CFLAGS="%{optflags}"
# crashes the xdist workers
donttest="test_operator_intersection"
# gh#serge-sans-paille/pythran#2044 NOT FIXED by gh#serge-sans-paille/pythran#2046
donttest="$donttest or test_toolchain or test_cli"
%pytest %{?jobs:-n %jobs} -k "not ($donttest)" -m "not module"
%endif

%if !%{with test}
%post
%python_install_alternative pythran pythran-config

%postun
%python_uninstall_alternative pythran

%files %{python_files}
%doc AUTHORS Changelog README.rst
%license LICENSE
%python_alternative %{_bindir}/pythran
%python_alternative %{_bindir}/pythran-config
%{python_sitelib}/pythran
%{python_sitelib}/omp
%{python_sitelib}/pythran-%{version}.dist-info
%endif

%changelog
* Wed Nov 29 2023 Steve Kowalik <steven.kowalik@suse.com>
- Prepare for Python 3.12, by skipping it for the other test flavors, and
  adding one for it.
* Tue Nov 21 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.14.0:
  * Numpy compatibility - update signatures, complex number handling, long
    double support
  * Lazyly import top-level modules and submodules
  * Improve array indexing by an array
  * Require at least clang 7 or gcc 8
  * Make pythran compilation reproducible
  * Support np.roll with multiple axis
  * Support numpy.ndarray.view
  * Improve list resizing speed
  * Fix bug when filtering an empty sequence
- Drop patches, now included upstream:
  * numpy-longdouble.patch
  * numpy-complex.patch
- Switch to pyproject macros.
* Tue Aug  8 2023 ecsos <ecsos@opensuse.org>
- Fix build error in Leap, because it must not be two "Patch:" lines.
* Thu Jul 27 2023 Markéta Machová <mmachova@suse.com>
- Add upstream numpy-longdouble.patch and numpy-complex.patch to support new numpy
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon May 15 2023 Dirk Müller <dmueller@suse.com>
- update to 0.13.1:
  * Bump xsimd dependency to 11.0.0, with a backported patch.
  * Improve performance of functions revieving scalar arguments.
    This changes the internal function call API.
  * Improve performance of fix-stride slicing, using a new slice
    representation.
  * Improve numpy.copyto performance, and detect copyto pattern usage.
  * Force internal linkage of generated functions, which gives more
    optimization room to the C++ compiler.
  * Provide entry points pythran.import_pythrancode and
    pythran.import_pythranfile, as a poor man JIT option.
  * Optimize numpy.argmax(cst * val) into numpy.argmax(val) when cst is
    positive.
  * Avoid copies upon numpy.array_split
  * Get rid of unused functions C++ warnings
  * Avoid generating a loop footer when the loop index is not used
    outside of the loop.
- fix the test-flavor splitting for python311
* Wed Jan 25 2023 Dirk Müller <dmueller@suse.com>
- update to 0.12.1:
  * Bump xsimd depdency to 10.0.0
  * Correctly raise KeyError when getting an unset dict item
  * Fix negative binomial implementation
  * Correctly convert strided array with offset
  * Support np.clip(v, None, x) and np.clip(v, x, None)
  * Support scipy.special.ndtr, scipy.special.ndtri, scipy.special.gammaincinv
  * Fix set intersection
  * Support numpy.fft.fftn
  * Support axis parameter in numpy.argsort
* Sun Dec 25 2022 Ben Greiner <code@bnavigator.de>
- Revert. 2046-fix-cli-doc-test.patch did not fix the tests.
  gh#serge-sans-paille/pythran#2046
* Sat Dec 17 2022 Matej Cepl <mcepl@suse.com>
- Add 2046-fix-cli-doc-test.patch to fix failing tests
  (gh#serge-sans-paille/pythran#2046).
* Fri Nov 25 2022 Matej Cepl <mcepl@suse.com>
- Skip also failing test_toolchain and test_cli
  (gh#serge-sans-paille/pythran#2044) tests.
* Tue Oct 11 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.12.0
  * Improve numpy expression computation speed
  * Decent ICC support (fixing an issue from 2018!)
  * Much faster C++ code generation
  * Complete rework of constant folder
  * Support C++-time evaluation of numpy.ndarray.ndim
  * Improved omp declare reduction support
  * Allow indexing of ndarray by integers of mixed types
  * A lot of small pesty bug fixes in the C++ headers
- Drop patches
  * gcc12-fixes.patch
  * pythran-pr1984-fixdistutils.patch
* Mon Jul 18 2022 Ben Greiner <code@bnavigator.de>
- Add pythran-pr1984-fixdistutils.patch
  * gh#serge-sans-paille/pythran#1984
  * Fixes gh#serge-sans-paille/pythran#1984 with setuptools >= 60
* Tue Mar 15 2022 Martin Liška <mliska@suse.cz>
- Add gcc12-fixes.patch in order to fix GCC 12 building issues.
* Fri Jan 28 2022 Ben Greiner <code@bnavigator.de>
- Fix errors uncovered by staging:
  * Mention python-pythran-rpmlintrc
  * also make :test-py* noarch so that no debuginfo package fails
* Sun Jan 23 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for 0.11
  * debundling inspired by Fedora package:
    https://src.fedoraproject.org/rpms/pythran/blob/rawhide/f/pythran.spec
- Required by scipy 1.7
